@@ -1,12 +1,16 @@
-from .ApiUtils import api_get, api_post
+from .api_service import ApiService, autobricks_logging
 from wheel_inspect import inspect_wheel
 from dataclasses import dataclass
 import os
 
+_logger = autobricks_logging.get_logger(__name__)
+
+_api_service = ApiService()
+
 
 def library_all_cluster_statuses():
 
-    return api_get("libraries", "all-cluster-statuses")
+    return _api_service.api_get("libraries", "all-cluster-statuses")
 
 
 @dataclass
